library(testthat)
library(assignPOP)

#test_check("assignPOP")
